PEP: 596 Title: Python 3.9 Release Schedule Version: \$Revision\$
Last-Modified: \$Date\$ Author: Łukasz Langa \<<lukasz@python.org>\>
Discussions-To:
<https://discuss.python.org/t/pep-596-python-3-9-release-schedule-doubling-the-release-cadence/1828>
Status: Draft Type: Informational Content-Type: text/x-rst Created:
04-Jun-2019 Python-Version: 3.9

Abstract
========

This document describes the development and release schedule for Python
3.9. The schedule primarily concerns itself with PEP-sized items.

Release Manager and Crew
========================

-   3.9 Release Manager: Łukasz Langa
-   Windows installers: Steve Dower
-   Mac installers: Ned Deily
-   Documentation: Julien Palard

Release Schedule
================

3.9.0 schedule
--------------

Note: the dates below use a 17-month development period that results in
a 12-month release cadence between major versions, as defined by PEP
602.

Actual:

-   3.9 development begins: Tuesday, 2019-06-04
-   3.9.0 alpha 1: Tuesday, 2019-11-19
-   3.9.0 alpha 2: Wednesday, 2019-12-18
-   3.9.0 alpha 3: Saturday, 2020-01-25
-   3.9.0 alpha 4: Wednesday, 2020-02-26
-   3.9.0 alpha 5: Monday, 2020-03-23
-   3.9.0 alpha 6: Tuesday, 2020-04-28
-   3.9.0 beta 1: Monday, 2020-05-18 (No new features beyond this
    point.)
-   3.9.0 beta 3: Tuesday, 2020-06-09 (beta 2 was recalled.)
-   3.9.0 beta 4: Friday, 2020-07-03
-   3.9.0 beta 5: Monday, 2020-07-20
-   3.9.0 candidate 1: Tuesday, 2020-08-11
-   3.9.0 candidate 2: Thursday, 2020-09-17

Expected:

-   3.9.0 final: Monday, 2020-10-05

Subsequent bugfix releases every two months, starting with:

-   3.9.1 candidate 1: Monday, 2020-11-23
-   3.9.1 final: Monday, 2020-12-07

3.9 Lifespan
------------

3.9 will receive bugfix updates approximately every 2 months for
approximately 18 months. Some time after the release of 3.10.0 final,
the ninth and final 3.9 bugfix update will be released. After that, it
is expected that security updates (source only) will be released until 5
years after the release of 3.9 final, so until approximately October
2025.

Features for 3.9
================

Implemented PEPs for 3.9 (as of 3.9.0 beta 1):

-   `584`{.interpreted-text role="pep"}, Add Union Operators To dict
-   `585`{.interpreted-text role="pep"}, Type Hinting Generics In
    Standard Collections
-   `593`{.interpreted-text role="pep"}, Flexible function and variable
    annotations
-   `614`{.interpreted-text role="pep"}, Relaxing Grammar Restrictions
    On Decorators
-   `615`{.interpreted-text role="pep"}, Support for the IANA Time Zone
    Database in the Standard Library
-   `616`{.interpreted-text role="pep"}, String methods to remove
    prefixes and suffixes
-   `617`{.interpreted-text role="pep"}, New PEG parser for CPython

Copyright
=========

This document has been placed in the public domain.

### 

> Local Variables: mode: indented-text indent-tabs-mode: nil
> sentence-end-double-space: t fill-column: 72 coding: utf-8 End:
